@@ -1,5 +1,6 @@
 
-#library(testthat)
+#
+library(testthat)
 #detach(package:vcfR, unload=TRUE)
 library(vcfR)
 context("genotype matrix functions")
