@@ -2,13 +2,12 @@
 
 
 library(vcfR)
-library(testthat)
+#library(testthat)
 context("maf")
 
-data("vcfR_example")
-
 
 test_that("maf works on vcfR",{
+  data("vcfR_example")
   my.maf <- maf(vcf)
 
   expect_equal( ncol(my.maf), 4 )
